/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.sinfo.importitem;

import java.util.List;

import org.apache.log4j.Logger;
import org.dive4elements.river.importer.common.AbstractSeriesImport;
import org.dive4elements.river.model.River;
import org.dive4elements.river.model.sinfo.BedMobility;
import org.dive4elements.river.model.sinfo.BedMobilityValue;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Imported bed mobility data series of a river
 *
 * @author Matthias Schäfer
 *
 */
public class BedMobilitySeriesImport extends AbstractSeriesImport<BedMobility, BedMobilityValue, BedMobilityKmLineImport> {

    /***** FIELDS *****/

    private static Logger log = Logger.getLogger(BedMobilitySeriesImport.class);


    /***** CONSTRUCTORS *****/

    public BedMobilitySeriesImport(final String filename) {
        super(filename);
    }


    /***** METHODS *****/

    @Override
    public Logger getLog() {
        return log;
    }

    @Override
    public List<BedMobility> querySeriesItem(final Session session, final River river) {
        final Query query = session.createQuery("FROM BedMobility WHERE river=:river");
        query.setParameter("river", river);
        return query.list();
    }


    @Override
    public BedMobility createSeriesItem(final River river) {
        return new BedMobility(river, this.filename, this.kmrange_info, this.comment);
    }
}